@@ -5,20 +5,20 @@
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
-        <location filename="../mainwindow.cpp" line="76"/>
-        <location filename="../mainwindow.cpp" line="460"/>
+        <location filename="../mainwindow.cpp" line="73"/>
+        <location filename="../mainwindow.cpp" line="467"/>
         <source>MX Cleanup</source>
-        <translation>Limpador do MX</translation>
+        <translation>Limpeza Automática do MX</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="696"/>
         <source>Clean Flatpak</source>
-        <translation type="unfinished"></translation>
+        <translation>Limpeza de Flatpak</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="702"/>
         <source>Remove unused runtimes</source>
-        <translation type="unfinished"></translation>
+        <translation>Remover o runtimes que não estiver sendo utilizado</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="718"/>
@@ -28,12 +28,12 @@
     <message>
         <location filename="../mainwindow.ui" line="737"/>
         <source>Not accessed for:</source>
-        <translation type="unfinished"></translation>
+        <translation>Não foi acessado para:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="805"/>
         <source>All (potentially dangerous)</source>
-        <translation type="unfinished"></translation>
+        <translation>Todos (potencialmente perigosos)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="59"/>
@@ -72,7 +72,7 @@
     </message>
     <message>
         <location filename="../mainwindow.ui" line="143"/>
-        <location filename="../mainwindow.cpp" line="535"/>
+        <location filename="../mainwindow.cpp" line="541"/>
         <source>Close</source>
         <translation>Fechar</translation>
     </message>
@@ -89,30 +89,34 @@
     <message>
         <location filename="../mainwindow.ui" line="216"/>
         <source>Empty Trash</source>
-        <translation>Esvaziar o Lixo</translation>
+        <translation>Esvaziar a Lixeira</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="222"/>
         <source>Trash older than:</source>
-        <translation>Lixo com mais de:</translation>
+        <translation>A lixeira está com mais de:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="235"/>
         <location filename="../mainwindow.ui" line="372"/>
         <location filename="../mainwindow.ui" line="590"/>
         <source>Don&apos;t empty</source>
-        <translation>Não esvaziar</translation>
+        <translation>Não esvaziar a lixeira</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="245"/>
         <location filename="../mainwindow.ui" line="622"/>
         <location filename="../mainwindow.ui" line="724"/>
-        <location filename="../mainwindow.cpp" line="339"/>
-        <location filename="../mainwindow.cpp" line="341"/>
-        <location filename="../mainwindow.cpp" line="343"/>
+        <location filename="../mainwindow.cpp" line="335"/>
+        <location filename="../mainwindow.cpp" line="338"/>
+        <location filename="../mainwindow.cpp" line="342"/>
         <source> days</source>
         <translation>dias</translation>
     </message>
+    <message>
+        <source>Not accessed for</source>
+        <translation type="vanished">Não foi acessado por</translation>
+    </message>
     <message>
         <location filename="../mainwindow.ui" line="264"/>
         <source>All users</source>
@@ -126,7 +130,7 @@
     <message>
         <location filename="../mainwindow.ui" line="331"/>
         <source>Clear APT Cache</source>
-        <translation>Limpar a memória cache APT</translation>
+        <translation>Limpar a memória cache do APT</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="343"/>
@@ -141,27 +145,27 @@
     <message>
         <location filename="../mainwindow.ui" line="404"/>
         <source>Graphical Tool for Analyzing Disk Usage</source>
-        <translation>Ferramenta gráfica para analisar o uso do disco</translation>
+        <translation>Ferramenta Gráfica para Analisar o Uso do Disco</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="416"/>
         <source>Run Disk Usage Analyzer</source>
-        <translation>Executar o analisador de uso de disco</translation>
+        <translation>Executar o Analisador de Uso do Disco</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="430"/>
         <source>Schedule</source>
-        <translation>Agendar limpeza automática</translation>
+        <translation>Agendar a limpeza automática</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="442"/>
         <source>No automatic clean</source>
-        <translation>Nunca</translation>
+        <translation>Não fazer a limpeza automática</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="449"/>
         <source>At reboot</source>
-        <translation type="unfinished"></translation>
+        <translation>Na reinicialização</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="456"/>
@@ -187,7 +191,7 @@
         <location filename="../mainwindow.ui" line="511"/>
         <location filename="../mainwindow.ui" line="527"/>
         <source>Select user to repair</source>
-        <translation>Selecione o usuário para reparar</translation>
+        <translation>Selecione o usuário para ser reparado</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="514"/>
@@ -197,7 +201,7 @@
     <message>
         <location filename="../mainwindow.ui" line="543"/>
         <source>Delete Logs</source>
-        <translation>Eliminar os registros (Logs)</translation>
+        <translation>Eliminar os Registros (Logs)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="568"/>
@@ -212,69 +216,69 @@
     <message>
         <location filename="../mainwindow.ui" line="641"/>
         <source>Logs older than:</source>
-        <translation>Registros com mais de:</translation>
+        <translation>Os registros estão com mais de:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="664"/>
         <source>Kernel removal tool</source>
-        <translation type="unfinished"></translation>
+        <translation>Ferramenta de remoção de núcleo (kernel)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="676"/>
         <source>List and select kernels to remove</source>
-        <translation type="unfinished"></translation>
+        <translation>Listar e selecionar os núcleos (kernels) para serem removidos</translation>
     </message>
     <message>
+        <location filename="../mainwindow.cpp" line="335"/>
         <location filename="../mainwindow.cpp" line="339"/>
-        <location filename="../mainwindow.cpp" line="341"/>
         <location filename="../mainwindow.cpp" line="343"/>
         <source> day</source>
-        <translation type="unfinished"></translation>
+        <translation>dia</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="453"/>
+        <location filename="../mainwindow.cpp" line="459"/>
         <source>Done</source>
         <translation>Concluído</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="453"/>
+        <location filename="../mainwindow.cpp" line="460"/>
         <source>Cleanup command done</source>
-        <translation>Comando de limpeza concluído</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="454"/>
-        <source>%1 MiB were freed</source>
-        <translation>%1 MiB foram limpos</translation>
+        <translation>O comando de limpeza foi concluído com sucesso</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="460"/>
+        <source>%1 MiB were freed</source>
+        <translation>%1 MiB foram liberados</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="467"/>
         <source>About</source>
         <translation>Sobre</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="462"/>
+        <location filename="../mainwindow.cpp" line="468"/>
         <source>Version: </source>
         <translation>Versão:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="463"/>
+        <location filename="../mainwindow.cpp" line="470"/>
         <source>Quick and safe removal of old files</source>
         <translation>Remoção rápida e segura de arquivos antigos</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="465"/>
+        <location filename="../mainwindow.cpp" line="472"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Direitos de Autor (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="467"/>
+        <location filename="../mainwindow.cpp" line="473"/>
         <source>%1 License</source>
-        <translation type="unfinished"></translation>
+        <translation>Licença do %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="474"/>
+        <location filename="../mainwindow.cpp" line="480"/>
         <source>%1 Help</source>
-        <translation type="unfinished"></translation>
+        <translation>Ajuda do %1</translation>
     </message>
     <message>
         <source>License</source>
@@ -293,68 +297,68 @@
         <translation type="vanished">&amp;Fechar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="530"/>
+        <location filename="../mainwindow.cpp" line="536"/>
         <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="533"/>
-        <source>Remove selected</source>
-        <translation>Remover os Itens Selecionados</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="538"/>
-        <source>Similar kernels that can be removed:</source>
-        <translation type="unfinished"></translation>
+        <translation>O núcleo (kernel) atualmente em uso é &lt;b&gt;%1&lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="539"/>
-        <source>Other kernels that can be removed:</source>
-        <translation type="unfinished"></translation>
+        <source>Remove selected</source>
+        <translation>Remover os itens selecionados</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="541"/>
+        <location filename="../mainwindow.cpp" line="544"/>
+        <source>Similar kernels that can be removed:</source>
+        <translation>Os núcleos (kernels) similares que podem ser removidos:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="545"/>
+        <source>Other kernels that can be removed:</source>
+        <translation>Outros núcleos (kernels) que podem ser removidos:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="547"/>
         <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Não pode ser removido.&lt;/b&gt; Não é possível remover o núcleo (kernel) que está em uso.</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="50"/>
+        <location filename="../main.cpp" line="51"/>
         <source>Quick safe removal of old files</source>
-        <translation type="unfinished"></translation>
+        <translation>Remoção rápida e segura de arquivos antigos</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="71"/>
+        <location filename="../main.cpp" line="74"/>
         <source>Error</source>
-        <translation>Erro</translation>
+        <translation>Ocorreu um erro</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="72"/>
+        <location filename="../main.cpp" line="75"/>
         <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
         <translation>Ao que parece, você está acessando a sessão com o usuário root. Por favor, saia da sessão atual e entre novamente com o usuário normal para utilizar este programa.</translation>
     </message>
-    <message>
-        <location filename="../about.cpp" line="50"/>
-        <source>License</source>
-        <translation type="unfinished">Licença</translation>
-    </message>
-    <message>
-        <location filename="../about.cpp" line="51"/>
-        <location filename="../about.cpp" line="60"/>
-        <source>Changelog</source>
-        <translation type="unfinished">Relatório de alterações</translation>
-    </message>
     <message>
         <location filename="../about.cpp" line="52"/>
-        <source>Cancel</source>
-        <translation type="unfinished">Cancelar</translation>
+        <source>License</source>
+        <translation>Licença</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="70"/>
+        <location filename="../about.cpp" line="53"/>
+        <location filename="../about.cpp" line="62"/>
+        <source>Changelog</source>
+        <translation>Relatório de Alterações</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="54"/>
+        <source>Cancel</source>
+        <translation>Cancelar</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="74"/>
         <source>&amp;Close</source>
-        <translation type="unfinished">&amp;Fechar</translation>
+        <translation>&amp;Fechar</translation>
     </message>
 </context>
 </TS>
